Dog Days of Denver Denver, Colorado July 31st 2005 3R+F 10 players Jeff Goss Here is the break down on the Nozzy/Dom deck from the tournament at Valhallas. This is a little different than what I played in Friday's tourney. I added some non-nos that can do the same job because I saw too many cards that messed with all one clan decks. Crypt (13 cards, min=9, max=40, avg=6) -------------------------------------- 5x Lucretia, Cess Queen 10 ANI OBF aus cel for pot primogen Nosferatu:1 1x Nikolaus Vermeulen 7 POT ani for obf prince Nosferatu:2 1x Agatha 4 POT obf Nosferatu antitribu:2 1x Roland Bishop 4 aus dom obf Malkavian:1 1x Sammy 4 ani obf pot Nosferatu:1 1x Duck 3 obf pot Nosferatu:1 1x Dimple 2 obf Nosferatu:1 1x KoKo 2 pot Nosferatu:1 1x Ohanna 2 dom Malkavian:2 Library (60 cards) Master (19) 1x Barrens, The 1x Blood Doll 7x Dominate 2x Elder Library 1x Information Highway 1x KRCG News Radio 2x Labyrinth, The 1x Minion Tap 1x Short-Term Investment 1x Slum Hunting Ground 1x Sudden Reversal Action (6) 1x Blood Bond 3x Govern the Unaligned 1x Nosferatu Performance Art -- for those pesky Toreadors 1x Patagia: Flaps Allowing Limited Flight Equipment (4) 1x .44 Magnum 2x Laptop Computer 1x Sport Bike Political Action (2) 1x Ancient Influence 1x Nosferatu Justicar Action Modifier (11) 3x Cloak the Gathering 2x Conditioning 2x Faceless Night 2x Lost in Crowds 1x Spying Mission 1x Threats Reaction (11) 6x Deflection 5x Wake with Evening's Freshness Combat (7) 3x Dodge 4x Thrown Gate